@@ -9,7 +9,7 @@ use Symbol 'gensym';
 use IPC::Open3;
 use utf8;
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 # Find Asciidoc.
 my $ASCIIDOC;
@@ -18,8 +18,12 @@ FIND: {
         File::Spec->path,
         WIN32 ? (map { "C:\\asciidoc$_" } '', '-8.6.6') : ()
     );
+    my @names = (
+        (map { (WIN32 ? ("$_.exe", "$_.bat") : ($_)) } qw(asciidoc)),
+        'asciidoc.py',
+    );
     EXE: {
-        for my $exe (qw(asciidoc asciidoc.py)) {
+        for my $exe (@names) {
             for my $p (@path) {
                 my $path = File::Spec->catfile($p, $exe);
                 next unless -f $path && -x $path;
@@ -32,8 +36,9 @@ FIND: {
     unless ($ASCIIDOC) {
         use Carp;
         my $sep = WIN32 ? ';' : ':';
+        my $list = join(', ', @names[0..$#names-1]) . ", or $names[-1]";
         Carp::croak(
-            "Cannot find asciidoc or asciidoc.py in path " . join $sep => @path
+            "Cannot find $list in path " . join $sep => @path
         );
     }
 
@@ -91,9 +96,8 @@ $html
 
 # Stolen from SVN::Notify.
 sub _fh {
-    # Ignored; looks like docutils always emits UTF-8.
     if (WIN32) {
-        my $cmd = join join(q{" "}, @_) . q{"|};
+        my $cmd = q{"} . join(q{" "}, @_) . q{"|};
         open my $fh, $cmd or die "Cannot fork: $!\n";
         return $fh;
     }
@@ -126,11 +130,13 @@ Text::Markup::Asciidoc - Asciidoc parser for Text::Markup
 
 =head1 Description
 
-This is the L<Asciidoc|http://www.methods.co.nz/asciidoc/> parser for
-L<Text::Markup>. It depends on the C<asciidoc> command-line application, for
-which there are many
-L<binary distributions|http://www.methods.co.nz/asciidoc/INSTALL.html>. It
-recognizes files with the following extensions as Asciidoc:
+This is the L<Asciidoc|https://asciidoc-py.github.io> parser for
+L<Text::Markup>. It depends on the C<asciidoc> command-line application,
+which See the L<installation docs|https://asciidoc-py.github.io/INSTALL.html>
+for details, or use the command C<pip install asciidoc>.
+
+Text::Markup::Asciidoc recognizes files with the following extensions as
+Asciidoc:
 
 =over
 
