@@ -4,7 +4,7 @@ use 5.8.1;
 use strict;
 use warnings;
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 sub parser {
     my ($file, $encoding, $opts) = @_;
@@ -30,8 +30,8 @@ Text::Markup::HTML - HTML parser for Text::Markup
 
 =head1 Description
 
-This is the L<HTML|http://whatwg.org/html/> parser for L<Text::Markup>. All it
-does is read in the HTML file and return it as a string. It makes no
+This is the L<HTML|https://whatwg.org/html/> parser for L<Text::Markup>. All
+it does is read in the HTML file and return it as a string. It makes no
 assumptions about encoding, and returns the string raw as read from the file,
 with no decoding. It recognizes files with the following extensions as HTML:
 
@@ -53,7 +53,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 Copyright and License
 
-Copyright (c) 2011-2019 David E. Wheeler. Some Rights Reserved.
+Copyright (c) 2011-2023 David E. Wheeler. Some Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
