@@ -4,9 +4,9 @@ use 5.8.1;
 use strict;
 use warnings;
 use File::BOM qw(open_bom);
-use Text::Textile '2.10';
+use Text::Textile 2.10;
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 sub parser {
     my ($file, $encoding, $opts) = @_;
@@ -48,9 +48,9 @@ Text::Markup::Textile - Textile parser for Text::Markup
 
 =head1 Description
 
-This is the L<Textile|http://www.textism.com/tools/textile/> parser for
-L<Text::Markup>. It reads in the file (relying on a
-L<BOM|http://www.unicode.org/unicode/faq/utf_bom.html#BOM>), hands it off to
+This is the L<Textile|https://textile-lang.com> parser for L<Text::Markup>.
+It reads in the file (relying on a
+L<BOM|https://www.unicode.org/unicode/faq/utf_bom.html#BOM>), hands it off to
 L<Text::Textile> for parsing, and then returns the generated HTML as an
 encoded UTF-8 string with an C<http-equiv="Content-Type"> element identifying
 the encoding as UTF-8.
@@ -73,7 +73,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 Copyright and License
 
-Copyright (c) 2011-2019 David E. Wheeler. Some Rights Reserved.
+Copyright (c) 2011-2023 David E. Wheeler. Some Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
